{% load i18n %}

<div id="tag-verification-error-container-{{ block_id }}" class="tag-verification-container tag-verification-{{ block_type }}" style="display: none;">
    <div>
        <h1>{% translate "Problem connecting" %}</h1>
        <p>{% translate "We couldn’t send your feedback. Please check your internet connection and try again." %}</p>
        <button onclick="tagVerificationRetry('{{ block_id }}')">{% translate "Try again" %}</button>
    </div>
</div>
