{% load i18n %}

<div class="tag-verification-form-container">
    <h1>{% translate "What did you learn?" %}</h1>
    <p>
        {% if block_type == 'vertical' %}
            {% translate "Congratulations, you've reached the end of this unit!" %}<br>
            {% translate "Help future students by selecting the skills or subjects you learned from this unit." %}
        {% elif block_type == 'video' %}
            {% translate "Help future students by selecting the skills or subjects you learned from this video." %}
        {% endif %}
    </p>
    <div id="tag-verification-tags-container-id-{{ block_id }}" class="tag-verification-tags-container">
        {% for skill in skills %}
        <input type="checkbox" name="tag-verification-skills-{{ block_id }}" id="tag-verification-skill-{{ block_id }}-{{ skill.name }}"
            value="{{ skill.id }}" onclick="tagVerificationOnSkillClick(this, '{{ block_id }}')">
        <label for="tag-verification-skill-{{ block_id }}-{{ skill.name }}"
            class="tag-verification-chip tag-verification-chip-clickable tag-verification-chip-hover">
            {{ skill.name }}
        </label>
        {% endfor %}
    </div>
    <div class="tag-verification-none-selected-container">
        <input type="checkbox" onClick="tagVerificationOnNoneCheckboxClick(this, '{{ block_id }}')"
            id="tagVerificationUnselectAllId-{{ block_id }}" />
        <label for="tagVerificationUnselectAllId-{{ block_id }}" class="tag-verification-none-selected">
            {% translate "None of these subjects were covered" %}
        </label>
    </div>
    <button id="tagVerificationSubmitButton-{{ block_id }}" disabled
        onclick="tagVerificationVerifyTags(this, '{{ verify_tags_url }}', '{{ block_id }}')">
        {% translate "Submit" %}
    </button>
</div>
