{% load i18n %}

<div id="tag-verification-thankyou-container-{{ block_id }}" class="tag-verification-container tag-verification-{{ block_type }}" style="display: none;">
    <div>
        <h1>{% translate "Thank you!" %}</h1>
        <p>
            {% translate "Your feedback has helped to improve this course. The selections you made will assist future learners to decide if this course is right for them." %}
        </p>
    </div>
</div>
