.tag-verification-vertical {
    margin-top: 20px;
    background: #F2F0EF;
    padding: 70px 65px;
}

.tag-verification-video {
    display: flex;
    justify-content: center;
    align-items: center;
    position: absolute;
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
    background: black;
    z-index: 0;
}

.tag-verification-video * {
    text-align: center;
    justify-content: center;
    color: white;
}

.tag-verification-container {
    border-radius: 6px;
    display: flex;
    box-sizing: border-box;
}

@media (max-width: 767px) {
   .tag-verification-image-container {
      display: none;
   }
}

.tag-verification-container h1 {
    font-style: normal;
    font-weight: 700;
    font-size: 32px;
    line-height: 28px;
    margin-bottom: 20px !important;
}

.tag-verification-vertical button {
    background: #00262B;
    color: #FFFFFF;
}

.tag-verification-video button {
    background: white;
    color: #00262B;
    width: fit-content;
    align-self: center;
}

.tag-verification-container button {
    padding: 10px 16px;
    font-weight: 500;
    font-size: 18px;
    line-height: 24px;
    box-shadow: none;
}

.tag-verification-video .tag-verification-form-container {
    display: flex;
    flex-direction: column;
}

.tag-verification-video p {
    width: 465px;
    align-self: center;
}

.tag-verification-vertical button:hover, .tag-verification-vertical button:focus {
    background: #00262B;
    color: #FFFFFF;
    border: 1px solid #00262B;
    box-shadow: none;
}

.tag-verification-video button:hover, .tag-verification-video button:focus {
    background: #065683;
    color: white;
    border: 1px solid #065683;
    box-shadow: none;
}

.tag-verification-container p {
    font-style: normal;
    font-weight: 400;
    font-size: 18px;
    line-height: 28px;
}

.tag-verification-vertical p {
    color: #454545;
}

.tag-verification-tags-container {
    flex-direction: row;
    align-items: center;
    display: flex;
    gap: 11px;
    margin-bottom: 20px;
    flex-wrap: wrap;
}

.tag-verification-chip {
    display: inline-block;
    font-size: 13px;
    padding: 2px 8px;
    box-sizing: border-box;
    border-radius: 6px;
    font-style: normal;
    font-weight: 400;
    font-size: 12px;
    line-height: 24px;
    margin-bottom: 0px;
}

.tag-verification-vertical .tag-verification-chip {
    color: #002121;
    background-color: white;
    border: 1px solid #F2F0EF;
}

.tag-verification-video .tag-verification-chip {
    color: white;
    background-color: #2D494E;
    border: 1px solid #2D494E;
}

.tag-verification-vertical .tag-verification-chip.tag-verification-chip-hover:hover {
    background: #ccc;
}

.tag-verification-video .tag-verification-chip.tag-verification-chip-hover:hover {
    background: #576D71;
}

.tag-verification-chip-clickable {
    cursor: pointer;
}

.tag-verification-tags-container input[type=checkbox] {
    position: absolute;
    /* set same dimensions as the SVG */
    width: 1em;
    height: 1em;
    /* hide it */
    opacity: 0.00000;
}

.tag-verification-vertical .tag-verification-tags-container input[type=checkbox]:checked + label {
    border: 1px solid #00262B;
}

.tag-verification-vertical .tag-verification-tags-container input[type=checkbox]:focus + label {
    background: #ccc;
}

.tag-verification-video .tag-verification-tags-container input[type=checkbox]:checked + label {
    border: 1px solid #FFFFFF;
}

.tag-verification-video .tag-verification-tags-container input[type=checkbox]:focus + label {
    background: #576D71;
}

.tag-verification-none-selected-container {
    margin-bottom: 25px;
    height: 28px;
    display: flex;
    align-items: center;
}

.tag-verification-none-selected-container label {
    font-weight: 400;
    font-size: 14px;
    line-height: 28px;
    margin: 0px;
}

.tag-verification-none-selected-container input {
    margin-right: 8px;
    width: 18px;
    height: 18px;
}


/* loading spinner */
.tag-verification-container button.loading {
    padding-left: 40px;
    position: relative;
}

.tag-verification-container button.loading:before {
    content: "";
    position: absolute;
    border-radius: 100%;
    left: 13px;
    top: 50%;
    width: 0px;
    height: 0px;
    margin-top: -2px;
    animation: spin .6s infinite linear, grow .3s forwards ease-out;
}

.tag-verification-vertical button.loading:before {
    border: 2px solid rgba(255,255,255,0.5);
    border-top-color: #FFF;
}

.tag-verification-video button.loading:before {
    border: 2px solid rgba(0,0,0,1);
    border-top-color: #FFF;
}

@keyframes spin {
    to {
        transform: rotate(359deg);
    }
}
@keyframes grow {
    to {
        width: 14px;
        height: 14px;
        margin-top: -8px;
        right: 13px;
    }
}

.tag-verification-container button[disabled] {
    opacity: 0.3;
}
